pub struct MultiCommandSender { /* private fields */ }Implementations
Sourceimpl MultiCommandSender
impl MultiCommandSender
pub fn new() -> Self
pub fn add_sender(&mut self, sender: CommandSender)
Sourcepub async fn send_command(&mut self, command: &str) -> Result<String>
pub async fn send_command(&mut self, command: &str) -> Result<String>
Send a command through the first available sender. Returns the response text from the first successful sender.
Sourcepub async fn send_command_ignore_response(
&mut self,
command: &str,
) -> Result<()>
pub async fn send_command_ignore_response( &mut self, command: &str, ) -> Result<()>
Send a command without caring about the response text.
pub fn is_empty(&self) -> bool